# file generated by setuptools_scm
# don't change, don't track in version control
__version__ = version = '0.2.1.dev9+gc250c0f.d20230406'
__version_tuple__ = version_tuple = (0, 2, 1, 'dev9', 'gc250c0f.d20230406')
